==> rh-quarkus-1.11.6-src.zip: rh-quarkus-1.11.6.GA-src/io.quarkus-quarkus-parent-1.11.6/ADOPTERS.md <==
ADOPTERS
========

PUBLIC REFERENCES
-----------------

This document lists the organizations that use Quarkus based on public information available in blog posts and videos. 
If any organization would like get added or removed please make a pull request by following these guidelines:

* Please don't include your organization's logo or other trademarked material
* Add a reference (link to a public blog post, video, slides, etc) mentioning that Quarkus is used

| Organization          | Reference                                                                        |
|-----------------------|----------------------------------------------------------------------------------|
|Artes                  | https://horvie.github.io/adopt-quarkus/                                          |
|B<>com                 | https://5g.labs.b-com.com/                                                       |
|Carrefour              | https://horizons.carrefour.com/efficient-java-in-the-cloud-with-quarkus          |
|Cytech                 | https://quarkus.io/blog/cytech-customer-story/                                   |
|Ennovative Solutions   | https://quarkus.io/blog/ennovativesolutions-uses-quarkus-with-aws-lambda/        |
|GoWithFlow             | https://quarkus.io/blog/gowithflow-chooses-quarkus-to-deliver-fast-to-production/|
|Lufthansa Technik      | https://quarkus.io/blog/aviatar-experiences-significant-savings/                 |
|Payair                 | https://quarkus.io/blog/why-did-payair-technologies-switch-to-quarkus/           |
|Sedona                 | https://quarkus.io/blog/sedona-rewrites-insurance-premium/                       |
|Suomen Asiakastieto Oy | https://quarkus.io/blog/asiakastieto-chooses-quarkus-for-microservices/          |
|Talkdesk               | https://quarkus.io/blog/talkdesk-chooses-quarkus-for-fast-innovation/            |
|UTN Faculty Córdoba    | https://www.frc.utn.edu.ar/computos/tech/                                        |
|Vodafone Greece        | https://quarkus.io/blog/vodafone-greece-replaces-spring-boot/                    |
|Wipro                  | https://quarkus.io/blog/wipro-customer-story/                                    |

==> rh-quarkus-2.7.6-src.zip: rh-quarkus-2.7.6.GA-src/io.quarkus-quarkus-parent-2.7.6/ADOPTERS.md <==
ADOPTERS
========

PUBLIC REFERENCES
-----------------

This document lists the organizations that use Quarkus based on public information available in blog posts and videos. 
If any organization would like get added or removed please make a pull request by following these guidelines:

* Please don't include your organization's logo or other trademarked material
* Add a reference (link to a public blog post, video, slides, etc) mentioning that Quarkus is used

| Organization          | Reference                                                                        |
|-----------------------|----------------------------------------------------------------------------------|
|Abraxas Informatik AG  | https://quarkus.io/blog/abraxas-customer-story/                                  |
|Artes                  | https://horvie.github.io/adopt-quarkus/                                          |
|B<>com                 | https://5g.labs.b-com.com/                                                       |
|Carrefour              | https://horizons.carrefour.com/efficient-java-in-the-cloud-with-quarkus          |
|Cytech                 | https://quarkus.io/blog/cytech-customer-story/                                   |
|Decathlon              | https://quarkus.io/blog/decathlon-user-story/                                    |
|Ennovative Solutions   | https://quarkus.io/blog/ennovativesolutions-uses-quarkus-with-aws-lambda/        |
|GoWithFlow             | https://quarkus.io/blog/gowithflow-chooses-quarkus-to-deliver-fast-to-production/|
|Lufthansa Technik      | https://quarkus.io/blog/aviatar-experiences-significant-savings/                 |
|Logicdrop              | https://quarkus.io/blog/logicdrop-customer-story/                                |
|Payair                 | https://quarkus.io/blog/why-did-payair-technologies-switch-to-quarkus/           |
|Sedona                 | https://quarkus.io/blog/sedona-rewrites-insurance-premium/                       |
|Suomen Asiakastieto Oy | https://quarkus.io/blog/asiakastieto-chooses-quarkus-for-microservices/          |
|Talkdesk               | https://quarkus.io/blog/talkdesk-chooses-quarkus-for-fast-innovation/            |
|UTN Faculty Córdoba    | https://www.frc.utn.edu.ar/computos/tech/                                        |
|Vodafone Greece        | https://quarkus.io/blog/vodafone-greece-replaces-spring-boot/                    |
|Wipro                  | https://quarkus.io/blog/wipro-customer-story/                                    |
